@@ -204,6 +204,7 @@ SUPPORTED_FEATURES = frozenset(
         "icecream",
         "installsources",
         "ipc-sandbox",
+        "jobserver-token",
         "keeptemp",
         "keepwork",
         "lmirror",
@@ -223,6 +224,7 @@ SUPPORTED_FEATURES = frozenset(
         "noman",
         "nostrip",
         "notitles",
+        "packdebug",
         "parallel-fetch",
         "parallel-install",
         "pid-sandbox",
